Learn R Programming

pracma (version 1.3.3)

clear, who: Clear function (Matlab style)

Description

List or remove items from workspace.

Usage

clear(lst)

what(dname = getwd()) who()

Arguments

lst
Character vector of names of variables in the global environment.
dname
(relative or absolute) directory path.

Value

  • Invisibly NULL.

Details

Remove these or all items from the workspace, i.e. the global environment, and freeing up system memory.

who lists all items on the workspace. what lists all files in a directory.

See Also

ls, rm

Examples

Run this code
# clear()  # DON'T
# what()
# who()

Run the code above in your browser using DataLab