Learn R Programming

pracma (version 1.3.1)

clear, who: Clear function (Matlab style)

Description

List or remove items from workspace.

Usage

clear(lst)
who()

Arguments

lst
Character vector of names of variables in the global environment.

Value

  • Invisibly NULL.

Details

Remove these or all items from the workspace, i.e. the global environment, and freeing up system memory.

who lists all items on the workspace.

See Also

ls, rm

Examples

Run this code
who()
# clear()  # DON'T

Run the code above in your browser using DataLab